@@ -34,6 +34,8 @@ as_track.sfc_POINT <- function(x, ...) {
 as_track.steps_xyt <- function(x, ...) {
   n <- nrow(x)
 
+  crs <- get_crs(x)
+
   if ("burst_" %in% names(x)) {
     xx <- tidyr::nest(x, data = -c(burst_)) %>%
       dplyr::mutate(data = purrr::map(data, function(y) {
@@ -44,14 +46,15 @@ as_track.steps_xyt <- function(x, ...) {
           t = c(y$t1_, y$t2_[n1])
         )
       })) %>% tidyr::unnest(cols = data)
-    make_track(xx, xs, ys, t, burst_ = burst_, crs = get_crs(x))
+    make_track(xx, xs, ys, t, burst_ = burst_,
+               crs = crs)
   } else {
     xx <- tibble::tibble(
       xs = c(x$x1_, x$x2_[n]),
       ys = c(x$y1_, x$y2_[n]),
       t = c(x$t1_, x$t2_[n])
     )
-    make_track(xx, xs, ys, t, crs = get_crs(x))
+    make_track(xx, xs, ys, t, crs = crs)
   }
 
 }
